---
Summary: Allow subheadings to create subcollections
Status: Not Fully Defined
---

# Description

Where we've got cards referenced in subheadings under headings, turn it into subcollections.

So

```markdown
# Key 1

## Key 2

[[card1]]
```

would add card1 to `Key 1` and `Key 1.Key 2`
